#include "board.h"
#include "io.h"
#include "types.h"
#include "gpio.h"
#include "i2c-gpio.h"
#include "da9063.h"

#define DA9063_ADDR	(0x5a)
#define ARRAY_SIZE(x)	(sizeof(x) / sizeof((x)[0]))

struct gpio_i2c_device da9063_dev = {
	.scl_pin	= PIN(7, 13),
	.sda_pin	= PIN(7, 14),
	.wait_usecs	= 6,
};

int da9063_read(u8 reg, int len, u8 *buf)
{
	u8 write_addr = (DA9063_ADDR<<1);
	u8 read_addr =  ((DA9063_ADDR<<1) | 1);
	struct i2c_msg msgs[] = {
		[0] = { &write_addr, 1, I2C_M_WR },
		[1] = { &reg, 1, I2C_M_WR },
		[2] = { &read_addr, 1, I2C_M_WR | I2C_REPSTART },
		[3] = { buf, len, I2C_M_RD },
	};

	return i2c_xfer(&da9063_dev, msgs, ARRAY_SIZE(msgs));
}

int da9063_write(u8 reg, int len, u8 *data)
{
	u8 write_addr = (DA9063_ADDR<<1);
	struct i2c_msg msgs[] = {
		[0] = { &write_addr, 1, I2C_M_WR },
		[1] = { &reg, 1, I2C_M_WR },
		[2] = { data, len, I2C_M_WR },
	};

	return i2c_xfer(&da9063_dev, msgs, ARRAY_SIZE(msgs));
}
